pub enum Phase {
Orient,
Plan,
Agree,
Execute,
Reflect,
Replan,
Report,
}Expand description
Workflow phase.
Transitions:
orient → plan
plan → agree
agree → execute
execute → reflect | report
reflect → execute | replan | report
replan → agree
report → (terminal)Variants
Implementations
Sourceimpl Phase
impl Phase
pub fn as_str(&self) -> &'static str
pub fn from_str(s: &str) -> Option<Self>
Sourcepub fn valid_transitions(&self) -> &'static [Phase]
pub fn valid_transitions(&self) -> &'static [Phase]
Phases reachable in a single phase set transition from here.
Sourcepub fn can_transition_to(&self, target: Phase) -> bool
pub fn can_transition_to(&self, target: Phase) -> bool
Whether transitioning from this phase to target is allowed
without --force.