pub fn current_phase_name( store: &Store, session_id: &str, ) -> Result<Option<String>>
Return the name of the current Phase claim for session_id, or None if no Phase claim exists (caller defaults to orient).
session_id
None
orient